import { BodyConfig, MessageType, SerializedMesh, ShapeConfig, UUID } from "../../lib/types";
import { RigidBody } from "../wrappers/rigid-body";
import { notImplementedEventReceiver } from "../utils";
import { Matrix4 } from "three";
export declare const bodies: Record<UUID, RigidBody>;
export declare const matrices: Record<UUID, Matrix4>;
export declare const indexes: Record<UUID, number>;
export declare const ptrToIndex: Record<number, number>;
export declare const ptrToRigidBody: Record<number, UUID>;
export declare const uuids: UUID[];
declare function addBody({ uuid, matrix, serializedMesh, shapeConfig, options, }: {
    uuid: UUID;
    matrix: number[];
    serializedMesh?: SerializedMesh;
    shapeConfig: ShapeConfig;
    options: BodyConfig;
}): void;
declare function updateBody({ uuid, options }: {
    uuid: any;
    options: any;
}): void;
declare function bodySetMotionState({ uuid, position, rotation }: {
    uuid: any;
    position: any;
    rotation: any;
}): void;
declare function bodySetLinearVelocity({ uuid, velocity }: {
    uuid: any;
    velocity: any;
}): void;
declare function bodyApplyImpulse({ uuid, impulse, relativeOffset }: {
    uuid: any;
    impulse: any;
    relativeOffset: any;
}): void;
declare function bodyApplyCentralImpulse({ uuid, impulse }: {
    uuid: any;
    impulse: any;
}): void;
declare function bodyApplyForce({ uuid, force, relativeOffset }: {
    uuid: any;
    force: any;
    relativeOffset: any;
}): void;
declare function bodyApplyCentralForce({ uuid, force }: {
    uuid: any;
    force: any;
}): void;
declare function removeBody({ uuid }: {
    uuid: any;
}): void;
declare function setShapesOffset({ bodyUuid, offset }: {
    bodyUuid: any;
    offset: any;
}): void;
declare function resetDynamicBody({ uuid }: {
    uuid: any;
}): void;
declare function activateBody({ uuid }: {
    uuid: any;
}): void;
export declare function copyToRigidBodyBuffer(): void;
export declare const rigidBodyEventReceivers: {
    3: typeof addBody;
    4: typeof updateBody;
    5: typeof removeBody;
    14: typeof setShapesOffset;
    12: typeof resetDynamicBody;
    13: typeof activateBody;
    15: typeof bodySetMotionState;
    16: typeof bodySetLinearVelocity;
    17: typeof notImplementedEventReceiver;
    20: typeof bodyApplyImpulse;
    21: typeof bodyApplyCentralImpulse;
    18: typeof bodyApplyForce;
    19: typeof bodyApplyCentralForce;
    22: typeof notImplementedEventReceiver;
    23: typeof notImplementedEventReceiver;
    24: typeof notImplementedEventReceiver;
    27: typeof notImplementedEventReceiver;
    25: typeof notImplementedEventReceiver;
    26: typeof notImplementedEventReceiver;
};
export {};
